Transpose
=========

.. figure:: icons/transpose.png

Maps data instances into features.

Signals
-------

**Inputs**:

-  **Data**

   Data set.

**Outputs**:

-  **Data**

   Transposed data set.

Description
-----------

A simple widget that maps data instances into features and vice versa.
